0.4.0  - Released on 2024-11-10
-------------------------------
* Reset base type Command, Event and Model as in 0.2
* New type GenericCommand, GenericEvent and GenericModel added as in 0.3

0.3.2  - Released on 2024-11-09
-------------------------------
* Cleanup documentation and CI 

0.3.1  - Released on 2024-11-01
-------------------------------
* Cosmetic fix of the README

0.3.0  - Released on 2024-11-01
-------------------------------
* Make the Message metadata a generic in order to inject custom metadata
* Drop support of python 3.7 and 3.8
* Switch packaging to uv / pdm
* Change license to MIT

0.2.2  - Released on 2024-09-27
-------------------------------
* Update for typing purpose

0.2.1  - Released on 2024-05-04
-------------------------------
* Remove files copy/pasted after rename of the package

0.2.0  - Released on 2024-01-04
-------------------------------
* Initialize seen list in repository
* Update dependencies
* Remove tests dependencies from package dependency

0.1.0 (unreleased yet)
----------------------
* Initial release
